Data
========

Data APIs provide utilities for loading, preprocessing, and managing datasets.

.. toctree::
   :maxdepth: 1

   data.base
   data.dataloaders
   data.datasets
   data.preprocessing
   data.scalers
   data.splitters
   data.backbone
   data.io
   data.utils
